@@ -2,6 +2,7 @@ from functools import wraps
 
 from django.http import HttpResponse
 from django.core.urlresolvers import reverse
+from django.core.handlers.wsgi import WSGIRequest
 from django.conf import settings
 
 from utils import redirect_to_facebook_authorization
@@ -16,11 +17,15 @@ def facebook_authorization_required(redirect_uri=False):
     """
     def decorator(function):
         @wraps(function)
-        def wrapper(request, *args, **kwargs):
+        def wrapper(*args, **kwargs):
+            
+            request = [arg for arg in args if arg.__class__ is WSGIRequest][0]
+            
             if not request.facebook or not request.facebook.user:
                     return redirect_to_facebook_authorization(
                         redirect_uri = redirect_uri or settings.FACEBOOK_APPLICATION_URL + request.get_full_path()
                     )
-            return function(request, *args, **kwargs)
+                    
+            return function(*args, **kwargs)
         return wrapper
     return decorator
