@@ -11,41 +11,41 @@ from settings import FACEBOOK_APPLICATION_URL, FACEBOOK_APPLICATION_SECRET_KEY,
 
 class FacebookMiddleware():
     """Middleware for Facebook applications."""
-    
+
     def process_request(self, request):
         """Populate request.facebook."""
-        
+
         if ENABLED_PATHS and DISABLED_PATHS:
             raise ImproperlyConfigured('You may configure either FANDJANGO_ENABLED_PATHS or FANDJANGO_DISABLED_PATHS, but not both.')
-        
+
         if DISABLED_PATHS and is_disabled_path(request.path):
             return
-        
+
         if ENABLED_PATHS and not is_enabled_path(request.path):
             return
-        
+
         # Signed request found in either GET, POST or COOKIES...
         if 'signed_request' in request.REQUEST or 'signed_request' in request.COOKIES:
             request.facebook = Facebook()
-            
+
             # If the request method is POST and its body only contains the signed request,
             # chances are it's a request from the Facebook platform and we'll override
             # the request method to HTTP GET to rectify their misinterpretation
             # of the HTTP protocol standard.
             #
-            # References: 
+            # References:
             # "POST for Canvas" migration at http://developers.facebook.com/docs/canvas/post/
             # "Incorrect use of the HTTP protocol" discussion at http://forum.developers.facebook.net/viewtopic.php?id=93554
             if request.method == 'POST' and 'signed_request' in request.POST:
                 request.method = 'GET'
-            
+
             request.facebook.signed_request = request.REQUEST.get('signed_request') or request.COOKIES.get('signed_request')
-            
+
             facebook_data = parse_signed_request(
                 signed_request = request.facebook.signed_request,
                 app_secret = FACEBOOK_APPLICATION_SECRET_KEY
             )
-            
+
             # The application is accessed from a tab on a Facebook page...
             if 'page' in facebook_data:
                 request.facebook.page = FacebookPage(
@@ -53,17 +53,16 @@ class FacebookMiddleware():
                     is_admin = facebook_data['page']['admin'],
                     is_liked = facebook_data['page']['liked']
                 )
-            
+
             # User has authorized the application...
             if 'user_id' in facebook_data:
-                
+
                 # Redirect to Facebook Authorization if the OAuth token has expired
-                if facebook_data['expires']:
-                    if datetime.fromtimestamp(facebook_data['expires']) < datetime.now():
+                if facebook_data['expires'] and datetime.fromtimestamp(facebook_data['expires']) < datetime.now():
                         return redirect_to_facebook_authorization(
                             redirect_uri = FACEBOOK_APPLICATION_URL + request.get_full_path()
                         )
-                
+
                 # Initialize a User object and its corresponding OAuth token
                 try:
                     user = User.objects.get(facebook_id=facebook_data['user_id'])
@@ -73,9 +72,9 @@ class FacebookMiddleware():
                         issued_at = datetime.fromtimestamp(facebook_data['issued_at']),
                         expires_at = datetime.fromtimestamp(facebook_data['expires'])
                     )
-                    
+
                     profile = get_facebook_profile(oauth_token.token)
-                    
+
                     user = User.objects.create(
                         facebook_id = profile.get('id'),
                         facebook_username = profile.get('username'),
@@ -99,15 +98,16 @@ class FacebookMiddleware():
                     user.last_seen_at = datetime.now()
                     user.authorized = True
                     user.save()
-                    
+
                     if facebook_data.has_key('oauth_token'):
                         user.oauth_token.token = facebook_data['oauth_token']
                         user.oauth_token.issued_at = datetime.fromtimestamp(facebook_data['issued_at'])
                         user.oauth_token.expires_at = datetime.fromtimestamp(facebook_data['expires']) if facebook_data['expires'] else None
                         user.oauth_token.save()
-                
+
                 request.facebook.user = user
-                
+
+        # ... no signed request found.
         else:
             request.facebook = False
 
@@ -115,11 +115,10 @@ class FacebookMiddleware():
     def process_response(self, request, response):
         """
         Set compact P3P policies and save signed request to cookie.
-        
+
         P3P is a WC3 standard (see http://www.w3.org/TR/P3P/), and although largely ignored by most
         browsers it is considered by IE before accepting third-party cookies (ie. cookies set by
         documents in iframes). If they are not set correctly, IE will not set these cookies.
-        
         """
         if 'signed_request' in request.REQUEST:
             response.set_cookie('signed_request', request.REQUEST['signed_request'])
